%define major          33
%define libname        %mklibname %name %major
%define libnamedev     %mklibname %name -d
%define libname_sce    %mklibname %name-engine-sce %major
%define libnamedev_sce %mklibname %name-engine-sce -d

Name:           openscap
Version:        1.4.2
Release:        %mkrel 2
Summary:        Set of open source libraries enabling integration of the SCAP line of standards
Group:          System/Libraries
License:        LGPLv2+
URL:            https://www.open-scap.org/
# https://fedorahosted.org/releases/o/p/openscap/%%{name}-%%{version}.tar.gz
Source0:        https://github.com/OpenSCAP/openscap/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  libacl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  openldap-devel
BuildRequires:  rpm-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libcap)
# re-enable when an upstream port to procps 4.x
#BuildRequires:  pkgconfig(libproc2)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(opendbx)
BuildRequires:  pkgconfig(xmlsec1)
BuildRequires:  pkgconfig(xmlsec1-openssl)
BuildRequires:  pkgconfig(yaml-0.1)

%description
OpenSCAP is a set of open source libraries providing an easier path
for integration of the SCAP line of standards. SCAP is a line of standards
managed by NIST with the goal of providing a standard language
for the expression of Computer Network Defense related information.

%package -n %{libname}
Summary:        Set of open source libraries enabling integration of the SCAP line of standards
Group:          System/Libraries

%description -n %{libname}
OpenSCAP is a set of open source libraries providing an easier path
for integration of the SCAP line of standards. SCAP is a line of standards
managed by NIST with the goal of providing a standard language
for the expression of Computer Network Defense related information.


%package -n %{libnamedev}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{libnamedev}
The %{libnamedev} package contains libraries and header files for
developing applications that use %{name}.

%package -n     python3-%{name}
Summary:        Python 3 bindings for %{name}
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
BuildRequires:  pkgconfig(python3)

Provides:       openscap-python3 = %{version}-%{release}

%description -n python3-%{name}
The python3-%{name} package contains the bindings so that %{name}
libraries can be used by python3.

%package        perl
Summary:        Perl bindings for %{name}
Group:          Development/Perl
Requires:       %{name} = %{version}-%{release}
BuildRequires:  perl-devel

%description    perl
The %{name}-perl package contains the bindings so that %{name}
libraries can be used by perl.

%package        scanner
Summary:        OpenSCAP Scanner Tool (oscap)
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
BuildRequires:  pkgconfig(libcurl)

%description    scanner
The %{name}-scanner package contains oscap command-line tool. The oscap
is configuration and vulnerability scanner, capable of performing
compliance checking using SCAP content.

%package        utils
Summary:        OpenSCAP Utilities
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-scanner = %{version}-%{release}
Requires:       rpmdevtools
Requires:       rpm-build

%description    utils
The %{name}-utils package contains command-line tools build on top
of OpenSCAP library. Historically, openscap-utils included oscap
tool which is now separated to %{name}-scanner sub-package.

%package -n %{libname_sce}
Summary:        Script Check Engine plug-in for OpenSCAP
Group:          System/Libraries

%description -n %{libname_sce}
The Script Check Engine is non-standard extension to SCAP protocol. This
engine allows content authors to avoid OVAL language and write their assessment
commands using a scripting language (Bash, Perl, Python, Ruby, ...).

%package -n    %{libnamedev_sce}
Summary:        Development files for %{libname_sce}
Group:          Development/C
Requires:       %{libnamedev} = %{version}-%{release}
Requires:       %{libname_sce} = %{version}-%{release}
Provides:       %{name}-engine-sce-devel = %{version}-%{release}

%description -n %{libnamedev_sce}
The %{libnamedev_sce} package contains libraries and header files
for developing applications that use %{libname_sce}.

%package        containers
Summary:        Utils for scanning containers
Group:          System/Base
Requires:       %{name} >= %{version}-%{release}
Requires:       %{name}-scanner
BuildArch:      noarch

%description    containers
Tool for scanning Atomic containers.

%prep
%autosetup -p1

%build
# gconf is a legacy system not used any more, and it blocks testing of oscap-anaconda-addon
# as gconf is no longer part of the installation medium
%cmake \
       -DENABLE_DOCS=ON \
       -DENABLE_PROBES=ON \
       -DWITH_PCRE2=ON \
       -DOPENSCAP_PROBE_UNIX_GCONF=OFF \
       -DCMAKE_SHARED_LINKER_FLAGS=""

%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS README.md
%license COPYING
%doc %{_docdir}/%{name}/manual/
%{_datadir}/%{name}/

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n python3-%{name}
%{python3_sitearch}/*

%files perl
%{perl_vendorarch}/*
%{perl_vendorlib}/openscap_pm.pm

%files -n %{libnamedev}
%doc docs/{html,examples}/
%{_docdir}/%{name}/html/
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%exclude %{_includedir}/%{name}/sce_engine_api.h

%files -n %{libnamedev_sce}
%{_libdir}/lib%{name}_sce.so
%{_includedir}/%{name}/sce_engine_api.h

%files scanner
%{_sysconfdir}/bash_completion.d/oscap
%{_bindir}/oscap
%{_mandir}/man8/oscap.8*

%files utils
%doc docs/oscap-scan.cron
%{_bindir}/autotailor
%{_bindir}/oscap-chroot
%{_bindir}/oscap-im
%{_bindir}/oscap-podman
%{_bindir}/oscap-run-sce-script
%{_bindir}/oscap-ssh
%{_bindir}/oscap-vm
%{_bindir}/scap-as-rpm
%{_mandir}/man8/autotailor.8*
%{_mandir}/man8/oscap-chroot.8*
%{_mandir}/man8/oscap-im.8.*
%{_mandir}/man8/oscap-podman.8*
%{_mandir}/man8/oscap-ssh.8*
%{_mandir}/man8/oscap-vm.8*
%{_mandir}/man8/scap-as-rpm.8*

%files -n %{libname_sce}
%{_libdir}/lib%{name}_sce.so.%{major}{,.*}

%files containers
%{_bindir}/oscap-docker
%{_mandir}/man8/oscap-docker.8*
%{python3_sitelib}/oscap_docker_python/


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 1.4.2-2.mga10
+ Revision: 2250901
- Mageia 10 Mass Rebuild

* Sun Apr 06 2025 daviddavid <daviddavid> 1.4.2-1.mga10
+ Revision: 2174016
- new version: 1.4.2

* Sun Mar 16 2025 wally <wally> 1.4.1-3.mga10
+ Revision: 2164976
- rebuild for libxml2 2.13.6

* Tue Mar 04 2025 wally <wally> 1.4.1-2.mga10
+ Revision: 2160412
- rebuild for python3.13

* Wed Jan 08 2025 daviddavid <daviddavid> 1.4.1-1.mga10
+ Revision: 2136113
- new version: 1.4.1

* Fri Nov 29 2024 daviddavid <daviddavid> 1.4.0-1.mga10
+ Revision: 2120010
- new version: 1.4.0
- now libmajor is 33

* Fri Aug 23 2024 tv <tv> 1.3.10-2.mga10
+ Revision: 2089690
- Rebuild for perl-5.40

* Tue Mar 26 2024 daviddavid <daviddavid> 1.3.10-1.mga10
+ Revision: 2052294
- new version: 1.3.10

* Thu Dec 28 2023 daviddavid <daviddavid> 1.3.9-6.mga10
+ Revision: 2023260
- rebuild for py3.12

* Tue Dec 05 2023 daviddavid <daviddavid> 1.3.9-5.mga10
+ Revision: 2013200
- add fedora patch to fix implicit declarations due to missing include
- rebuild for new perl 5.38.0

* Sun Nov 12 2023 daviddavid <daviddavid> 1.3.9-4.mga10
+ Revision: 2006242
- rebuild for new rpm 4.19.0

* Sun Nov 05 2023 daviddavid <daviddavid> 1.3.9-3.mga10
+ Revision: 2004642
- disable procps support until an upstream port to 4.x

* Tue Sep 26 2023 daviddavid <daviddavid> 1.3.9-2.mga10
+ Revision: 1991164
- switch to pcre2

* Wed Sep 20 2023 daviddavid <daviddavid> 1.3.9-1.mga10
+ Revision: 1988453
- new version: 1.3.9

* Mon Aug 28 2023 daviddavid <daviddavid> 1.3.8-1.mga10
+ Revision: 1980394
- new version: 1.3.8
+ wally <wally>
- do not own /etc/bash_completion.d/

* Sat Jan 28 2023 daviddavid <daviddavid> 1.3.7-1.mga9
+ Revision: 1936630
- new version: 1.3.7
- remove merged upstream patches

* Thu Nov 24 2022 daviddavid <daviddavid> 1.3.6-4.mga9
+ Revision: 1910886
- add some patches from fedora

* Tue Jun 07 2022 umeabot <umeabot> 1.3.6-3.mga9
+ Revision: 1862677
- Rebuild for Perl 5.36

* Sun Apr 03 2022 umeabot <umeabot> 1.3.6-2.mga9
+ Revision: 1841555
- Mageia 9 Mass Rebuild

* Sun Feb 27 2022 mrambo3501 <mrambo3501> 1.3.6-1.mga9
+ Revision: 1786367
- version 1.3.6
- update files list
- rebuild for python-3.10
+ wally <wally>
- rebuild for openssl 3.0.0

* Mon May 24 2021 umeabot <umeabot> 1.3.5-2.mga9
+ Revision: 1726377
- Rebuild for perl 5.34

* Tue Apr 27 2021 daviddavid <daviddavid> 1.3.5-1.mga9
+ Revision: 1720008
- new version: 1.3.5

* Sat Mar 20 2021 daviddavid <daviddavid> 1.3.4-2.mga9
+ Revision: 1705305
- rebuild for python 3.9

* Wed Oct 21 2020 daviddavid <daviddavid> 1.3.4-1.mga8
+ Revision: 1637550
- new version: 1.3.4

* Wed Jun 17 2020 umeabot <umeabot> 1.3.3-2.mga8
+ Revision: 1594236
- Rebuild for perl 5.32

* Thu Apr 30 2020 daviddavid <daviddavid> 1.3.3-1.mga8
+ Revision: 1573434
- new version: 1.3.3

* Wed Feb 19 2020 umeabot <umeabot> 1.3.2-3.mga8
+ Revision: 1544378
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 1.3.2-2.mga8
+ Revision: 1482902
- rebuild for new procps-ng 3.3.16

* Tue Jan 21 2020 daviddavid <daviddavid> 1.3.2-1.mga8
+ Revision: 1481830
- new version: 1.3.2
- remove merged upstream patches
+ wally <wally>
- build with new cmake macros

* Sun Sep 15 2019 daviddavid <daviddavid> 1.3.1-3.mga8
+ Revision: 1441146
- backport pmatilai's patches for RPM 4.15 build fix
- rebuild for python3.8

* Tue Aug 27 2019 tmb <tmb> 1.3.1-2.mga8
+ Revision: 1433997
- rebuild for perl 5.30

* Sun Jun 30 2019 daviddavid <daviddavid> 1.3.1-1.mga8
+ Revision: 1416369
- new version: 1.3.1

* Thu Apr 04 2019 daviddavid <daviddavid> 1.3.0-1.mga7
+ Revision: 1385723
- new version: 1.3.0
- switch to cmake build system
- now libmajor is 25
- python2 support was removed upstream
- content-sectool, extra-probes and extra-probes-sql were removed upstream

* Tue Jan 08 2019 tv <tv> 1.2.17-3.mga7
+ Revision: 1352214
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.2.17-2.mga7
+ Revision: 1300033
- Mageia 7 Mass Rebuild

* Tue May 29 2018 daviddavid <daviddavid> 1.2.17-1.mga7
+ Revision: 1232948
- new version: 1.2.17
- rename and rediff link patch

* Tue Dec 26 2017 daviddavid <daviddavid> 1.2.16-1.mga7
+ Revision: 1185254
- new version: 1.2.16
- fix build adding LIBS=-ldl

* Fri Sep 01 2017 daviddavid <daviddavid> 1.2.15-2.mga7
+ Revision: 1150416
- rebuild for new rpm

* Fri Aug 25 2017 daviddavid <daviddavid> 1.2.15-1.mga7
+ Revision: 1147767
- new version: 1.2.15
- rename openscap-python to python2-openscap
- rename openscap-python3 to python3-openscap

* Fri Aug 04 2017 daviddavid <daviddavid> 1.2.14-2.mga7
+ Revision: 1134772
- rebuild for Python 3.6

* Wed Jul 19 2017 daviddavid <daviddavid> 1.2.14-1.mga7
+ Revision: 1124996
- new version: 1.2.14
- update URL and Source URL

* Thu Jun 29 2017 pterjan <pterjan> 1.2.13-2.mga6
+ Revision: 1108662
- Add a call to autoreconf to fix build with new automake

* Fri Jan 06 2017 daviddavid <daviddavid> 1.2.13-1.mga6
+ Revision: 1080332
- new version: 1.2.13

* Wed Nov 23 2016 daviddavid <daviddavid> 1.2.12-1.mga6
+ Revision: 1069372
- new version: 1.2.12

* Thu Oct 20 2016 daviddavid <daviddavid> 1.2.11-1.mga6
+ Revision: 1062595
- new version: 1.2.11

* Fri Sep 02 2016 daviddavid <daviddavid> 1.2.10-1.mga6
+ Revision: 1049764
- new version: 1.2.10 (fixes mga#19253)
- sync partially with fedora
- enable python3 and sce support
- rename and rediff link patch

* Sat Jun 18 2016 pterjan <pterjan> 0.9.12-11.mga6
+ Revision: 1022170
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.9.12-10.mga6
+ Revision: 956550
- Mageia 6 Mass Rebuild

* Mon Sep 14 2015 fwang <fwang> 0.9.12-9.mga6
+ Revision: 879179
- drop all .la files

* Mon Sep 14 2015 fwang <fwang> 0.9.12-8.mga6
+ Revision: 879160
- rebuild for new libgcrypt

* Sun Sep 06 2015 tv <tv> 0.9.12-7.mga6
+ Revision: 873300
- rebuild with new rpm

* Wed Oct 15 2014 umeabot <umeabot> 0.9.12-6.mga5
+ Revision: 740551
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.12-5.mga5
+ Revision: 727525
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.12-4.mga5
+ Revision: 683240
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 0.9.12-2.mga4
+ Revision: 534741
- Mageia 4 Mass Rebuild

* Fri Sep 13 2013 sander85 <sander85> 0.9.12-1.mga4
+ Revision: 478687
- New version: 0.9.12

* Sun Jul 21 2013 sander85 <sander85> 0.9.11-1.mga4
+ Revision: 456903
- New version: 0.9.11
- rediff patches

* Sun Jan 13 2013 umeabot <umeabot> 0.8.5-5.mga3
+ Revision: 362134
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 pterjan <pterjan> 0.8.5-4.mga3
+ Revision: 337489
- Fix for _libdir != _libexecdir

* Tue Dec 18 2012 tv <tv> 0.8.5-3.mga3
+ Revision: 332297
- rebuild for new rpm

* Sat Dec 01 2012 fwang <fwang> 0.8.5-2.mga3
+ Revision: 323672
- rebuild for new pcre

* Fri Sep 14 2012 fwang <fwang> 0.8.5-1.mga3
+ Revision: 293878
- new version 0.8.5
- new version 0.8.1
+ tv <tv>
- rebuild for new rpm-4.10.0

* Sun Jan 15 2012 fwang <fwang> 0.8.0-1.mga2
+ Revision: 196409
- update filelist
- fix str fmt
- drop merged patch
- new version 0.8.0
- drop .la file

* Sun Apr 24 2011 pterjan <pterjan> 0.7.2-1.mga1
+ Revision: 90013
- libify
- update to 0.7.2
- fix pkg-config file
- imported package openscap


* Sun Mar 13 2011 Funda Wang <fwang@mandriva.org> 0.7.1-1mdv2011.0
+ Revision: 644115
- New version 0.7.1
- rediff rpm5 patch

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - rpm5 rebuild for contrib/release

* Wed Dec 08 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.6.3-3mdv2011.0
+ Revision: 616384
- add rpm5 support (P1)

* Fri Nov 19 2010 Funda Wang <fwang@mandriva.org> 0.6.3-2mdv2011.0
+ Revision: 598902
- rebuild for py2.7

* Mon Oct 18 2010 Oden Eriksson <oeriksson@mandriva.com> 0.6.3-1mdv2011.0
+ Revision: 586615
- 0.6.3

* Sat Sep 04 2010 Funda Wang <fwang@mandriva.org> 0.6.2-1mdv2011.0
+ Revision: 575813
- new version 0.6.2
- New version 0.6.2

* Sat Feb 27 2010 Funda Wang <fwang@mandriva.org> 0.5.7-1mdv2010.1
+ Revision: 512251
- BR curl
- update file list
- new version 0.5.7

* Tue Jan 26 2010 Eugeni Dodonov <eugeni@mandriva.com> 0.5.6-1mdv2010.1
+ Revision: 496752
- Fixed -devel group.
- Fixed groups for perl and python bindings.
- Imported into svn.
- Created package structure for openscap.

